@@ -7,9 +7,13 @@ from Crypto.Cipher import AES
 
 class AESCipher(object):
     """
-    A classical AES Cipher. Can use any size of data and any size of password thanks to padding.
-    Also ensure the coherence and the type of the data with a unicode to byte converter.
+
+    A classical AES Cipher. Can use any size of data and any size of
+    password thanks to padding.  Also ensure the coherence and the type of
+    the data with a unicode to byte converter.
+
     """
+
     def __init__(self, key):
         self.bs = 32
         self.key = hashlib.sha256(AESCipher.str_to_bytes(key)).digest()
@@ -22,7 +26,8 @@ class AESCipher(object):
         return data
 
     def _pad(self, s):
-        return s + (self.bs - len(s) % self.bs) * AESCipher.str_to_bytes(chr(self.bs - len(s) % self.bs))
+        return s + (self.bs - len(s) % self.bs) * AESCipher.str_to_bytes(
+            chr(self.bs - len(s) % self.bs))
 
     @staticmethod
     def _unpad(s):
