@@ -5,24 +5,24 @@ import re
 from datetime import datetime, timedelta
 
 import voluptuous as vo
-from funcy.colls import none
-from funcy.flow import silent
-from funcy.seqs import first
+from funcy import none, silent, first
 
 from steep.account import Account
 from steep.amount import Amount
 from steep.converter import Converter
 from steep.instance import shared_steemd_instance
 from steep.transactionbuilder import TransactionBuilder
-from steep.utils import derive_permlink, resolve_identifier, fmt_time_string, keep_in_dict
+from steep.utils import (
+    derive_permlink,
+    fmt_time_string,
+    keep_in_dict,
+    resolve_identifier,
+)
 from steep.wallet import Wallet
 from steepbase import memo
 from steepbase import operations
 from steepbase.account import PrivateKey, PublicKey
-from steepbase.exceptions import (
-    AccountExistsException,
-    MissingKeyError,
-)
+from steepbase.exceptions import AccountExistsException, MissingKeyError
 from steepbase.storage import configStorage
 
 log = logging.getLogger(__name__)
@@ -54,6 +54,7 @@ STEEMIT_1_PERCENT = (STEEMIT_100_PERCENT / 100)
 
 # enable_content_editing_operation [active]
 
+
 class Commit(object):
     """ Commit things to the Steem network.
 
@@ -111,11 +112,12 @@ class Commit(object):
                 posting permission. Neither can you use different
                 accounts for different operations!
         """
-        tx = TransactionBuilder(None,
-                                steemd_instance=self.steemd,
-                                wallet_instance=self.wallet,
-                                no_broadcast=self.no_broadcast,
-                                expiration=self.expiration)
+        tx = TransactionBuilder(
+            None,
+            steemd_instance=self.steemd,
+            wallet_instance=self.wallet,
+            no_broadcast=self.no_broadcast,
+            expiration=self.expiration)
         tx.appendOps(ops)
 
         if self.unsigned:
@@ -128,19 +130,20 @@ class Commit(object):
         return tx.broadcast()
 
     def sign(self, unsigned_trx, wifs=[]):
-        """ Sign a provided transaction witht he provided key(s)
+        """ Sign a provided transaction with the provided key(s)
 
             :param dict unsigned_trx: The transaction to be signed and returned
             :param string wifs: One or many wif keys to use for signing
                 a transaction. If not present, the keys will be loaded
                 from the wallet as defined in "missing_signatures" key
-                of the transactizions.
+                of the transactions.
         """
-        tx = TransactionBuilder(unsigned_trx,
-                                steemd_instance=self.steemd,
-                                wallet_instance=self.wallet,
-                                no_broadcast=self.no_broadcast,
-                                expiration=self.expiration)
+        tx = TransactionBuilder(
+            unsigned_trx,
+            steemd_instance=self.steemd,
+            wallet_instance=self.wallet,
+            no_broadcast=self.no_broadcast,
+            expiration=self.expiration)
         tx.appendMissingSignatures(wifs)
         tx.sign()
         return tx.json()
@@ -150,11 +153,12 @@ class Commit(object):
 
             :param tx signed_trx: Signed transaction to broadcast
         """
-        tx = TransactionBuilder(signed_trx,
-                                steemd_instance=self.steemd,
-                                wallet_instance=self.wallet,
-                                no_broadcast=self.no_broadcast,
-                                expiration=self.expiration)
+        tx = TransactionBuilder(
+            signed_trx,
+            steemd_instance=self.steemd,
+            wallet_instance=self.wallet,
+            no_broadcast=self.no_broadcast,
+            expiration=self.expiration)
         return tx.broadcast()
 
     def post(self,
@@ -171,54 +175,68 @@ class Commit(object):
              self_vote=False):
         """ Create a new post.
 
-        If this post is intended as a reply/comment, `reply_identifier` needs to be set with the identifier of the parent
-        post/comment (eg. `@author/permlink`).
+        If this post is intended as a reply/comment, `reply_identifier` needs
+        to be set with the identifier of the parent post/comment (eg.
+        `@author/permlink`).
 
-        Optionally you can also set json_metadata, comment_options and upvote the newly created post as an author.
+        Optionally you can also set json_metadata, comment_options and upvote
+        the newly created post as an author.
 
-        Setting category, tags or community will override the values provided in json_metadata and/or comment_options
-        where appropriate.
+        Setting category, tags or community will override the values provided
+        in json_metadata and/or comment_options where appropriate.
 
         Args:
-            title (str): Title of the post
-            body (str): Body of the post/comment
-            author (str): Account are you posting from
-            permlink (str): Manually set the permlink (defaults to None).
-                If left empty, it will be derived from title automatically.
-            reply_identifier (str): Identifier of the parent post/comment (only if this post is a reply/comment).
-            json_metadata (str, dict): JSON meta object that can be attached to the post.
-            comment_options (str, dict): JSON options object that can be attached to the post.
-                Example::
 
-                    comment_options = {
-                        'max_accepted_payout': '1000000.000 SBD',
-                        'percent_steem_dollars': 10000,
-                        'allow_votes': True,
-                        'allow_curation_rewards': True,
-                        'extensions': [[0, {
-                            'beneficiaries': [
-                                {'account': 'account1', 'weight': 5000},
-                                {'account': 'account2', 'weight': 5000},
-                            ]}
-                        ]]
-                    }
+        title (str): Title of the post
+        body (str): Body of the post/comment
+        author (str): Account are you posting from
+        permlink (str): Manually set the permlink (defaults to None).
+            If left empty, it will be derived from title automatically.
+        reply_identifier (str): Identifier of the parent post/comment (only
+            if this post is a reply/comment).
+        json_metadata (str, dict): JSON meta object that can be attached to
+            the post.
+        comment_options (str, dict): JSON options object that can be
+            attached to the post.
 
-            community (str): (Optional) Name of the community we are posting into. This will also override the
-                community specified in `json_metadata`.
-            tags (str, list): (Optional) A list of tags (5 max) to go with the post. This will also override the
-                tags specified in `json_metadata`. The first tag will be used as a 'category'.
-                If provided as a string, it should be space separated.
-            beneficiaries (list of dicts): (Optional) A list of beneficiaries for posting reward distribution.
-                This argument overrides beneficiaries as specified in `comment_options`.
-
-                For example, if we would like to split rewards between account1 and account2::
-
-                    beneficiaries = [
+        Example::
+            comment_options = {
+                'max_accepted_payout': '1000000.000 SBD',
+                'percent_steem_dollars': 10000,
+                'allow_votes': True,
+                'allow_curation_rewards': True,
+                'extensions': [[0, {
+                    'beneficiaries': [
                         {'account': 'account1', 'weight': 5000},
-                        {'account': 'account2', 'weight': 5000}
-                    ]
+                        {'account': 'account2', 'weight': 5000},
+                    ]}
+                ]]
+            }
+
+        community (str): (Optional) Name of the community we are posting
+            into. This will also override the community specified in
+            `json_metadata`.
+
+        tags (str, list): (Optional) A list of tags (5 max) to go with the
+            post. This will also override the tags specified in
+            `json_metadata`. The first tag will be used as a 'category'. If
+            provided as a string, it should be space separated.
+
+        beneficiaries (list of dicts): (Optional) A list of beneficiaries
+            for posting reward distribution. This argument overrides
+            beneficiaries as specified in `comment_options`.
+
+        For example, if we would like to split rewards between account1 and
+        account2::
+
+            beneficiaries = [
+                {'account': 'account1', 'weight': 5000},
+                {'account': 'account2', 'weight': 5000}
+            ]
+
+        self_vote (bool): (Optional) Upvote the post as author, right after
+            posting.
 
-            self_vote (bool): (Optional) Upvote the post as author, right after posting.
         """
 
         # prepare json_metadata
@@ -237,12 +255,10 @@ class Commit(object):
         category = None
         tags = tags or json_metadata.get('tags', [])
         if tags:
-            if len(tags) > 5:
-                raise ValueError('Can only specify up to 5 tags per post.')
-
             # first tag should be a category
-            category = tags[0]
-            json_metadata.update({"tags": tags[1:]})
+            category = derive_permlink(tags[0])
+            tags = [derive_permlink(i) for i in tags]
+            json_metadata.update({"tags": tags})
 
         # can't provide a category while replying to a post
         if reply_identifier and category:
@@ -265,14 +281,15 @@ class Commit(object):
                 permlink = derive_permlink(title)
 
         post_op = operations.Comment(
-            **{"parent_author": parent_author,
-               "parent_permlink": parent_permlink,
-               "author": author,
-               "permlink": permlink,
-               "title": title,
-               "body": body,
-               "json_metadata": json_metadata}
-        )
+            **{
+                "parent_author": parent_author,
+                "parent_permlink": parent_permlink,
+                "author": author,
+                "permlink": permlink,
+                "title": title,
+                "body": body,
+                "json_metadata": json_metadata
+            })
         ops = [post_op]
 
         # if comment_options are used, add a new op to the transaction
@@ -314,12 +331,12 @@ class Commit(object):
 
         if self_vote:
             vote_op = operations.Vote(
-                **{'voter': author,
-                   'author': author,
-                   'permlink': permlink,
-                   'weight': 10000,
-                   }
-            )
+                **{
+                    'voter': author,
+                    'author': author,
+                    'permlink': permlink,
+                    'weight': 10000,
+                })
             ops.append(vote_op)
 
         return self.finalizeOp(ops, author, "posting")
@@ -331,13 +348,13 @@ class Commit(object):
         """ Vote for a post
 
             :param str identifier: Identifier for the post to upvote Takes
-                                   the form ``@author/permlink``
+                                   the form ``author/permlink``
             :param float weight: Voting weight. Range: -100.0 - +100.0. May
                                  not be 0.0
             :param str account: Voter to use for voting. (Optional)
 
-            If ``voter`` is not defines, the ``default_account`` will be taken or
-            a ValueError will be raised
+            If ``voter`` is not defines, the ``default_account`` will be taken
+            or a ValueError will be raised
 
             .. code-block:: python
 
@@ -351,37 +368,39 @@ class Commit(object):
         post_author, post_permlink = resolve_identifier(identifier)
 
         op = operations.Vote(
-            **{"voter": account,
-               "author": post_author,
-               "permlink": post_permlink,
-               "weight": int(weight * STEEMIT_1_PERCENT)}
-        )
+            **{
+                "voter": account,
+                "author": post_author,
+                "permlink": post_permlink,
+                "weight": int(weight * STEEMIT_1_PERCENT)
+            })
 
         return self.finalizeOp(op, account, "posting")
 
-    def create_account(self,
-                       account_name,
-                       json_meta=None,
-                       password=None,
-                       owner_key=None,
-                       active_key=None,
-                       posting_key=None,
-                       memo_key=None,
-                       additional_owner_keys=[],
-                       additional_active_keys=[],
-                       additional_posting_keys=[],
-                       additional_owner_accounts=[],
-                       additional_active_accounts=[],
-                       additional_posting_accounts=[],
-                       store_keys=True,
-                       store_owner_key=False,
-                       delegation_fee_steem='0 STEEM',
-                       creator=None,
-                       ):
+    def create_account(
+            self,
+            account_name,
+            json_meta=None,
+            password=None,
+            owner_key=None,
+            active_key=None,
+            posting_key=None,
+            memo_key=None,
+            additional_owner_keys=[],
+            additional_active_keys=[],
+            additional_posting_keys=[],
+            additional_owner_accounts=[],
+            additional_active_accounts=[],
+            additional_posting_accounts=[],
+            store_keys=True,
+            store_owner_key=False,
+            delegation_fee_steem='0 STEEM',
+            creator=None,
+    ):
         """ Create new account in Steem
 
-            The brainkey/password can be used to recover all generated keys (see
-            `steepbase.account` for more details.
+            The brainkey/password can be used to recover all generated keys
+            (see `steepbase.account` for more details.
 
             By default, this call will use ``default_account`` to
             register a new name ``account_name`` with all keys being
@@ -390,18 +409,21 @@ class Commit(object):
             wallet.
 
             .. note:: Account creations cost a fee that is defined by
-                       the network. If you create an account, you will
-                       need to pay for that fee!
-                       
-                       **You can partially pay that fee by delegating VESTS.**
-                       
-                       To pay the fee in full in STEEM, leave ``delegation_fee_steem`` set to ``0 STEEM`` (Default).
-                       
-                       To pay the fee partially in STEEM, partially with delegated VESTS, set ``delegation_fee_steem``
-                       to a value greater than ``1 STEEM``. `Required VESTS will be calculated automatically.`
-                       
-                       To pay the fee with maximum amount of delegation, set ``delegation_fee_steem`` to ``1 STEEM``.
-                       `Required VESTS will be calculated automatically.`
+               the network. If you create an account, you will
+               need to pay for that fee!
+
+               **You can partially pay that fee by delegating VESTS.**
+
+               To pay the fee in full in STEEM, leave
+               ``delegation_fee_steem`` set to ``0 STEEM`` (Default).
+
+               To pay the fee partially in STEEM, partially with delegated
+               VESTS, set ``delegation_fee_steem`` to a value greater than ``1
+               STEEM``. `Required VESTS will be calculated automatically.`
+
+               To pay the fee with maximum amount of delegation, set
+               ``delegation_fee_steem`` to ``1 STEEM``. `Required VESTS will be
+               calculated automatically.`
 
             .. warning:: Don't call this method unless you know what
                           you are doing! Be sure to understand what this
@@ -425,19 +447,23 @@ class Commit(object):
                                  can provide a password from which the
                                  keys will be derived
             :param list additional_owner_keys:  Additional owner public keys
+
             :param list additional_active_keys: Additional active public keys
+
             :param list additional_posting_keys: Additional posting public keys
             :param list additional_owner_accounts: Additional owner account names
             :param list additional_active_accounts: Additional active account names
             :param list additional_posting_accounts: Additional posting account names
             :param bool store_keys: Store new keys in the wallet (default: ``True``)
             :param bool store_owner_key: Store owner key in the wallet (default: ``False``)
-            :param str delegation_fee_steem: (Optional) If set, `creator` pay a fee of this amount,
-                                        and delegate the rest with VESTS (calculated automatically).
-                                        Minimum: 1 STEEM. If left to 0 (Default), full fee is paid
-                                        without VESTS delegation.
+            :param str delegation_fee_steem: (Optional) If set, `creator` pay a
+            fee of this amount, and delegate the rest with VESTS (calculated
+            automatically). Minimum: 1 STEEM. If left to 0 (Default), full fee
+            is paid without VESTS delegation.
+
             :param str creator: which account should pay the registration fee
                                 (defaults to ``default_account``)
+
             :raises AccountExistsException: if the account already exists on the blockchain
 
         """
@@ -448,11 +474,9 @@ class Commit(object):
         if not creator:
             raise ValueError(
                 "Not creator account given. Define it with " +
-                "creator=x, or set the default_account using steempy")
+                "creator=x, or set the default_account using steeppy")
         if password and (owner_key or posting_key or active_key or memo_key):
-            raise ValueError(
-                "You cannot use 'password' AND provide keys!"
-            )
+            raise ValueError("You cannot use 'password' AND provide keys!")
 
         # check if account already exists
         try:
@@ -491,8 +515,7 @@ class Commit(object):
             memo_pubkey = PublicKey(memo_key, prefix=self.steemd.chain_params["prefix"])
         else:
             raise ValueError(
-                "Call incomplete! Provide either a password or public keys!"
-            )
+                "Call incomplete! Provide either a password or public keys!")
 
         owner = format(owner_pubkey, self.steemd.chain_params["prefix"])
         active = format(active_pubkey, self.steemd.chain_params["prefix"])
@@ -527,13 +550,15 @@ class Commit(object):
         required_fee_vests = 0
         delegation_fee_steem = Amount(delegation_fee_steem).amount
         if delegation_fee_steem:
-            # creating accounts without delegation requires 30x account_creation_fee
-            # creating account with delegation allows one to use VESTS to pay the fee
-            # where the ratio must satisfy 1 STEEM in fee == 5 STEEM in delegated VESTS
+            # creating accounts without delegation requires 30x
+            # account_creation_fee creating account with delegation allows one
+            # to use VESTS to pay the fee where the ratio must satisfy 1 STEEM
+            # in fee == 5 STEEM in delegated VESTS
+
             delegated_sp_fee_mult = 5
 
             if delegation_fee_steem < 1:
-                raise ValueError("When creating account with delegation, at least 1 STEEM in fee must be paid.")
+                raise ValueError("When creating account with delegation, at least 1 GOLOS in fee must be paid.")
 
             # calculate required remaining fee in vests
             remaining_fee = required_fee_steem - delegation_fee_steem
@@ -541,22 +566,30 @@ class Commit(object):
                 required_sp = remaining_fee * delegated_sp_fee_mult
                 required_fee_vests = Converter().sp_to_vests(required_sp) + 1
 
-        s = {'creator': creator,
-             'fee': '%s STEEM' % (delegation_fee_steem or required_fee_steem),
-             'delegation': '%s VESTS' % required_fee_vests,
-             'json_metadata': json_meta or {},
-             'memo_key': memo,
-             'new_account_name': account_name,
-             'owner': {'account_auths': owner_accounts_authority,
-                       'key_auths': owner_key_authority,
-                       'weight_threshold': 1},
-             'active': {'account_auths': active_accounts_authority,
-                        'key_auths': active_key_authority,
-                        'weight_threshold': 1},
-             'posting': {'account_auths': posting_accounts_authority,
-                         'key_auths': posting_key_authority,
-                         'weight_threshold': 1},
-             'prefix': self.steemd.chain_params["prefix"]}
+        s = {
+            'creator': creator,
+            'fee': '%s STEEM' % (delegation_fee_steem or required_fee_steem),
+            'delegation': '%s VESTS' % required_fee_vests,
+            'json_metadata': json_meta or {},
+            'memo_key': memo,
+            'new_account_name': account_name,
+            'owner': {
+                'account_auths': owner_accounts_authority,
+                'key_auths': owner_key_authority,
+                'weight_threshold': 1
+            },
+            'active': {
+                'account_auths': active_accounts_authority,
+                'key_auths': active_key_authority,
+                'weight_threshold': 1
+            },
+            'posting': {
+                'account_auths': posting_accounts_authority,
+                'key_auths': posting_key_authority,
+                'weight_threshold': 1
+            },
+            'prefix': self.steemd.chain_params["prefix"]
+        }
 
         op = operations.AccountCreateWithDelegation(**s)
 
@@ -566,6 +599,7 @@ class Commit(object):
         """ Transfer SBD or STEEM to another account.
 
             :param str to: Recipient
+
             :param float amount: Amount to transfer
             :param str asset: Asset to transfer (``SBD`` or ``STEEM``)
             :param str memo: (optional) Memo, may begin with `#` for encrypted messaging
@@ -590,20 +624,15 @@ class Commit(object):
                 PublicKey(to_account["memo_key"], prefix=self.steemd.chain_params["prefix"]),
                 nonce,
                 memo,
-                prefix=self.steemd.chain_params["prefix"]
-            )
+                prefix=self.steemd.chain_params["prefix"])
 
         op = operations.Transfer(
-            **{"from": account,
-               "to": to,
-               "amount": '{:.{prec}f} {asset}'.format(
-                   float(amount),
-                   prec=3,
-                   asset=asset
-               ),
-               "memo": memo
-               }
-        )
+            **{
+                "from": account,
+                "to": to,
+                "amount": '{:.{prec}f} {asset}'.format(float(amount), prec=3, asset=asset),
+                "memo": memo
+            })
         return self.finalizeOp(op, account, "active")
 
     def withdraw_vesting(self, amount, account=None):
@@ -632,10 +661,11 @@ class Commit(object):
     def transfer_to_vesting(self, amount, to=None, account=None):
         """ Vest STEEM
 
-            :param float amount: number of STEEM to vest
-            :param str to: (optional) the source account for the transfer if not ``default_account``
-            :param str account: (optional) the source account for the transfer if not ``default_account``
-        """
+        :param float amount: number of STEEM to vest
+        :param str to: (optional) the source account for the transfer if not ``default_account``
+        :param str account: (optional) the source account for the transfer if not ``default_account``
+
+    """
         if not account:
             account = configStorage.get("default_account")
         if not account:
@@ -659,9 +689,10 @@ class Commit(object):
     def convert(self, amount, account=None, request_id=None):
         """ Convert SteemDollars to Steem (takes one week to settle)
 
-            :param float amount: number of VESTS to withdraw over a period of 104 weeks
+            :param float amount: number of VESTS to withdraw
             :param str account: (optional) the source account for the transfer if not ``default_account``
             :param str request_id: (optional) identifier for tracking the conversion`
+
         """
         if not account:
             account = configStorage.get("default_account")
@@ -716,7 +747,13 @@ class Commit(object):
         )
         return self.finalizeOp(op, account, "active")
 
-    def transfer_from_savings(self, amount, asset, memo, request_id=None, to=None, account=None):
+    def transfer_from_savings(self,
+                              amount,
+                              asset,
+                              memo,
+                              request_id=None,
+                              to=None,
+                              account=None):
         """ Withdraw SBD or STEEM from 'savings' account.
 
             :param float amount: STEEM or SBD amount
@@ -834,7 +871,10 @@ class Commit(object):
         )
         return self.finalizeOp(op, account, "active")
 
-    def witness_feed_publish(self, steem_usd_price, quote="1.000", account=None):
+    def witness_feed_publish(self,
+                             steem_usd_price,
+                             quote="1.000",
+                             account=None):
         """ Publish a feed price as a witness.
 
             :param float steem_usd_price: Price of STEEM in USD (implied price)
@@ -920,8 +960,7 @@ class Commit(object):
         next_payment = last_payment + timedelta(days=30)
         interest_rate = self.steemd.get_dynamic_global_properties()["sbd_interest_rate"] / 100  # percent
         interest_amount = (interest_rate / 100) * int(
-            int(account["sbd_seconds"]) / (60 * 60 * 24 * 356)
-        ) * 10 ** -3
+            int(account["sbd_seconds"]) / (60 * 60 * 24 * 356)) * 10 ** -3
 
         return {
             "interest": interest_amount,
@@ -931,8 +970,11 @@ class Commit(object):
             "interest_rate": interest_rate,
         }
 
-    def set_withdraw_vesting_route(self, to, percentage=100,
-                                   account=None, auto_vest=False):
+    def set_withdraw_vesting_route(self,
+                                   to,
+                                   percentage=100,
+                                   account=None,
+                                   auto_vest=False):
         """ Set up a vesting withdraw route. When vesting shares are
             withdrawn, they will be routed to these accounts based on the
             specified weights.
@@ -970,8 +1012,12 @@ class Commit(object):
         if authority["weight_threshold"] > weights:
             raise ValueError("Threshold too restrictive!")
 
-    def allow(self, foreign, weight=None, permission="posting",
-              account=None, threshold=None):
+    def allow(self,
+              foreign,
+              weight=None,
+              permission="posting",
+              account=None,
+              threshold=None):
         """ Give additional access to an account by some other public
             key or account.
 
@@ -994,8 +1040,7 @@ class Commit(object):
 
         if permission not in ["owner", "posting", "active"]:
             raise ValueError(
-                "Permission needs to be either 'owner', 'posting', or 'active"
-            )
+                "Permission needs to be either 'owner', 'posting', or 'active")
         account = Account(account, steemd_instance=self.steemd)
         if not weight:
             weight = account[permission]["weight_threshold"]
@@ -1003,39 +1048,36 @@ class Commit(object):
         authority = account[permission]
         try:
             pubkey = PublicKey(foreign)
-            authority["key_auths"].append([
-                str(pubkey),
-                weight
-            ])
+            authority["key_auths"].append([str(pubkey), weight])
         except:
             try:
                 foreign_account = Account(foreign, steemd_instance=self.steemd)
-                authority["account_auths"].append([
-                    foreign_account["name"],
-                    weight
-                ])
+                authority["account_auths"].append([foreign_account["name"], weight])
             except:
                 raise ValueError(
-                    "Unknown foreign account or unvalid public key"
-                )
+                    "Unknown foreign account or unvalid public key")
         if threshold:
             authority["weight_threshold"] = threshold
             self._test_weights_treshold(authority)
 
         op = operations.AccountUpdate(
-            **{"account": account["name"],
-               permission: authority,
-               "memo_key": account["memo_key"],
-               "json_metadata": account["json_metadata"],
-               'prefix': self.steemd.chain_params["prefix"]}
-        )
+            **{
+                "account": account["name"],
+                permission: authority,
+                "memo_key": account["memo_key"],
+                "json_metadata": account["json_metadata"],
+                'prefix': self.steemd.chain_params["prefix"]
+            })
         if permission == "owner":
             return self.finalizeOp(op, account["name"], "owner")
         else:
             return self.finalizeOp(op, account["name"], "active")
 
-    def disallow(self, foreign, permission="posting",
-                 account=None, threshold=None):
+    def disallow(self,
+                 foreign,
+                 permission="posting",
+                 account=None,
+                 threshold=None):
         """ Remove additional access to an account by some other public
             key or account.
 
@@ -1054,34 +1096,28 @@ class Commit(object):
 
         if permission not in ["owner", "posting", "active"]:
             raise ValueError(
-                "Permission needs to be either 'owner', 'posting', or 'active"
-            )
+                "Permission needs to be either 'owner', 'posting', or 'active")
         account = Account(account, steemd_instance=self.steemd)
         authority = account[permission]
 
         try:
             pubkey = PublicKey(foreign, prefix=self.steemd.chain_params["prefix"])
             affected_items = list(
-                filter(lambda x: x[0] == str(pubkey),
-                       authority["key_auths"]))
-            authority["key_auths"] = list(filter(
-                lambda x: x[0] != str(pubkey),
-                authority["key_auths"]
-            ))
+                filter(lambda x: x[0] == str(pubkey), authority["key_auths"]))
+            authority["key_auths"] = list(
+                filter(lambda x: x[0] != str(pubkey), authority["key_auths"]))
         except:
             try:
                 foreign_account = Account(foreign, steemd_instance=self.steemd)
                 affected_items = list(
                     filter(lambda x: x[0] == foreign_account["name"],
                            authority["account_auths"]))
-                authority["account_auths"] = list(filter(
-                    lambda x: x[0] != foreign_account["name"],
-                    authority["account_auths"]
-                ))
+                authority["account_auths"] = list(
+                    filter(lambda x: x[0] != foreign_account["name"],
+                           authority["account_auths"]))
             except:
                 raise ValueError(
-                    "Unknown foreign account or unvalid public key"
-                )
+                    "Unknown foreign account or unvalid public key")
 
         removed_weight = affected_items[0][1]
 
@@ -1094,19 +1130,18 @@ class Commit(object):
         try:
             self._test_weights_treshold(authority)
         except:
-            log.critical(
-                "The account's threshold will be reduced by %d"
-                % removed_weight
-            )
+            log.critical("The account's threshold will be reduced by %d" %
+                         removed_weight)
             authority["weight_threshold"] -= removed_weight
             self._test_weights_treshold(authority)
 
         op = operations.AccountUpdate(
-            **{"account": account["name"],
-               permission: authority,
-               "memo_key": account["memo_key"],
-               "json_metadata": account["json_metadata"]}
-        )
+            **{
+                "account": account["name"],
+                permission: authority,
+                "memo_key": account["memo_key"],
+                "json_metadata": account["json_metadata"]
+            })
         if permission == "owner":
             return self.finalizeOp(op, account["name"], "owner")
         else:
@@ -1130,10 +1165,11 @@ class Commit(object):
         PublicKey(key)  # raises exception if invalid
         account = Account(account, steemd_instance=self.steemd)
         op = operations.AccountUpdate(
-            **{"account": account["name"],
-               "memo_key": key,
-               "json_metadata": account["json_metadata"]}
-        )
+            **{
+                "account": account["name"],
+                "memo_key": key,
+                "json_metadata": account["json_metadata"]
+            })
         return self.finalizeOp(op, account["name"], "active")
 
     def approve_witness(self, witness, account=None, approve=True):
@@ -1150,11 +1186,11 @@ class Commit(object):
         if not account:
             raise ValueError("You need to provide an account")
         account = Account(account, steemd_instance=self.steemd)
-        op = operations.AccountWitnessVote(
-            **{"account": account["name"],
-               "witness": witness,
-               "approve": approve,
-               })
+        op = operations.AccountWitnessVote(**{
+            "account": account["name"],
+            "witness": witness,
+            "approve": approve,
+        })
         return self.finalizeOp(op, account["name"], "active")
 
     def disapprove_witness(self, witness, account=None):
@@ -1168,7 +1204,11 @@ class Commit(object):
         """
         return self.approve_witness(witness=witness, account=account, approve=False)
 
-    def custom_json(self, id, json, required_auths=[], required_posting_auths=[]):
+    def custom_json(self,
+                    id,
+                    json,
+                    required_auths=[],
+                    required_posting_auths=[]):
         """ Create a custom json operation
 
             :param str id: identifier for the custom json (max length 32 bytes)
@@ -1184,10 +1224,12 @@ class Commit(object):
         else:
             raise Exception("At least one account needs to be specified")
         op = operations.CustomJson(
-            **{"json": json,
-               "required_auths": required_auths,
-               "required_posting_auths": required_posting_auths,
-               "id": id})
+            **{
+                "json": json,
+                "required_auths": required_auths,
+                "required_posting_auths": required_posting_auths,
+                "id": id
+            })
         return self.finalizeOp(op, account, "posting")
 
     def resteem(self, identifier, account=None):
@@ -1202,16 +1244,20 @@ class Commit(object):
         if not account:
             raise ValueError("You need to provide an account")
         author, permlink = resolve_identifier(identifier)
-        json_body = ["reblog", {"account": account,
-                                "author": author,
-                                "permlink": permlink}]
+        json_body = [
+            "reblog", {
+                "account": account,
+                "author": author,
+                "permlink": permlink
+            }
+        ]
         return self.custom_json(
             id="follow",
             json=json_body,
             required_posting_auths=[account]
         )
 
-    def unfollow(self, unfollow, what=["blog"], account=None):
+    def unfollow(self, unfollow, what=None, account=None):
         """ Unfollow another account's blog
 
             :param str unfollow: Follow this account
@@ -1221,9 +1267,10 @@ class Commit(object):
         """
         # FIXME: removing 'blog' from the array requires to first read
         # the follow.what from the blockchain
-        return self.follow(unfollow, what=[], account=account)
+        what = what or ['blog']
+        return self.follow(unfollow, what=what, account=account)
 
-    def follow(self, follow, what=["blog"], account=None):
+    def follow(self, follow, what=None, account=None):
         """ Follow another account's blog
 
             :param str follow: Follow this account
@@ -1236,9 +1283,13 @@ class Commit(object):
         if not account:
             raise ValueError("You need to provide an account")
 
-        json_body = ['follow', {'follower': account,
-                                'following': follow,
-                                'what': what}]
+        json_body = [
+            'follow', {
+                'follower': account,
+                'following': follow,
+                'what': what or ['blog']
+            }
+        ]
         return self.custom_json(
             id="follow",
             json=json_body,
@@ -1258,9 +1309,11 @@ class Commit(object):
             raise ValueError("You need to provide an account")
         account = Account(account, steemd_instance=self.steemd)
         op = operations.AccountUpdate(
-            **{"account": account["name"],
-               "memo_key": account["memo_key"],
-               "json_metadata": profile}
+            **{
+                "account": account["name"],
+                "memo_key": account["memo_key"],
+                "json_metadata": profile
+            }
         )
         return self.finalizeOp(op, account["name"], "active")
 
