@@ -7,9 +7,11 @@ class Witness(dict):
     """ Read data about a witness in the chain
 
         :param str witness: Name of the witness
-        :param Steemd steemd_instance: Steemd() instance to use when accessing a RPC
+        :param Steemd steemd_instance: Steemd() instance to use when
+        accessing a RPC
 
     """
+
     def __init__(self, witness, steemd_instance=None):
         self.steemd = steemd_instance or shared_steemd_instance()
         self.witness_name = witness
